# Things to do

## API Releated

- [x] Add support for getting segments
- [x] Add support for getting segments with hash
- [x] Add support for adding segments
- [x] Add support for voting segments
- [x] Add support for posting skipped segments
- [x] Add support for getting user information
- [x] Add support for getting view count
- [x] Add support for getting saved time
- [x] Add support for getting username
- [x] Add support for setting username
- [x] Add support for getting top users
- [x] Add support for getting total stats
- [x] Add support for getting detailed segment info
- [x] Add support for getting users via name
- [ ] Add support for getting database info
- [ ] Add support for locking

## Qualify of Life improvements

- [ ] Add utils for tabular printing
- [x] Use functools.ttl to cache stuff like top users
- [ ] Add async client

## Documentation

- [x] Write some more comments
- [x] Use sphinx better
- [x] Fix stuff in examples
- [ ] Add more pages to documentation

## Miscellaneous

- [x] Make a logo